![](/docs/source/_static/feste_logo.png)

## Feste

[![lint](https://github.com/perone/feste/actions/workflows/lint.yml/badge.svg)](https://github.com/perone/feste/actions/workflows/lint.yml) [![test](https://github.com/perone/feste/actions/workflows/test.yml/badge.svg)](https://github.com/perone/feste/actions/workflows/test.yml) [![codecov](https://codecov.io/gh/perone/feste/branch/main/graph/badge.svg?token=OP45ZTZ6QX)](https://codecov.io/gh/perone/feste) [![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

## ⚡ Installation

`pip install feste`

## 📖 Documentation

Please see [here](https://feste.readthedocs.io/en/latest/?) for the
documentation about:

- Installation
- Getting started
- Tutorials
- API documentation
